<?php


namespace Schaffen\ProductionOrder\ProductionOrder\Repositories;


use Schaffen\ProductionOrder\ProductionOrder\Models\Status;
use Freelabois\LaravelQuickstart\Extendables\Repository;
use Schaffen\WarehouseInventory\WarehouseInventory\Services\SnapshotService;

class StatusRepository extends Repository
{
    protected $model = Status::class;
    protected $searchableFields = [
    ];

    public function getWarehouseFlow($current_status, $next_status) {

        if (abs($next_status->st_codigo - $current_status->st_codigo) > 1) {
            throw new \Exception("Não é possivel mover uma ordem de produção do status {$current_status->st_descricao} para o status {$next_status->st_descricao}");
        }

        if ($next_status->isFinal()) {
            return [
                'warehouse_inventory_origin' => $current_status->st_fk_loe_codigo_destino,
                'warehouse_inventory_destiny' => null,
                'snap_op_mode' => SnapshotService::SNA_VALUE_REACALCULATE
            ];
        }

        if ($next_status->st_codigo > $current_status->st_codigo && boolval($next_status->st_controla_estoque)) {
            return [
                'warehouse_inventory_origin' => $next_status->st_fk_loe_codigo_origem,
                'warehouse_inventory_destiny' => $next_status->st_fk_loe_codigo_destino,
                'snap_op_mode' => SnapshotService::SNA_VALUE_COPY
            ];
        } else if ($current_status->st_codigo > $next_status->st_codigo && boolval($current_status->st_controla_estoque)) {
            return [
                'warehouse_inventory_origin' => $current_status->st_fk_loe_codigo_destino,
                'warehouse_inventory_destiny' => $current_status->st_fk_loe_codigo_origem,
                'snap_op_mode' => SnapshotService::SNA_VALUE_KEEP
            ];
        } else {
            return [
                'warehouse_inventory_origin' => null,
                'warehouse_inventory_destiny' => null,
                'snap_op_mode' => null
            ];
        }
    }
}
